@@ -3,6 +3,7 @@ from json import dumps
 from typing import TYPE_CHECKING, Generator, List, Optional, Union
 
 from ..const import API_PATH
+from ..util import _deprecate_args
 from .base import PRAWBase
 from .reddit.draft import Draft
 from .reddit.live import LiveThread
@@ -13,17 +14,17 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class DraftHelper(PRAWBase):
-    r"""Provide a set of functions to interact with :class:`Draft` instances.
+    r"""Provide a set of functions to interact with :class:`.Draft` instances.
 
     .. note::
 
         The methods provided by this class will only work on the currently authenticated
-        user's :class:`Draft`\ s.
+        user's :class:`.Draft`\ s.
 
     """
 
     def __call__(
-        self, *, draft_id: Optional[str] = None
+        self, draft_id: Optional[str] = None
     ) -> Union[List["praw.models.Draft"], "praw.models.Draft"]:
         """Return a list of :class:`.Draft` instances.
 
@@ -43,7 +44,7 @@ class DraftHelper(PRAWBase):
         .. code-block:: python
 
             draft_id = "124862bc-e1e9-11eb-aa4f-e68667a77cbb"
-            draft = reddit.drafts(draft_id=draft_id)
+            draft = reddit.drafts(draft_id)
             print(draft)
 
         """
@@ -110,7 +111,7 @@ class DraftHelper(PRAWBase):
 
         """
         if selftext and url:
-            raise TypeError("Exactly one of `selftext` or `url` must be provided.")
+            raise TypeError("Exactly one of 'selftext' or 'url' must be provided.")
         if isinstance(subreddit, str):
             subreddit = self._reddit.subreddit(subreddit)
 
@@ -132,12 +133,12 @@ class DraftHelper(PRAWBase):
 
 
 class LiveHelper(PRAWBase):
-    """Provide a set of functions to interact with LiveThreads."""
+    r"""Provide a set of functions to interact with :class:`.LiveThread`\ s."""
 
     def __call__(
         self, id: str
     ) -> "praw.models.LiveThread":  # pylint: disable=invalid-name,redefined-builtin
-        """Return a new lazy instance of :class:`~.LiveThread`.
+        """Return a new lazy instance of :class:`.LiveThread`.
 
         This method is intended to be used as:
 
@@ -187,23 +188,25 @@ class LiveHelper(PRAWBase):
 
         return generator()
 
+    @_deprecate_args("title", "description", "nsfw", "resources")
     def create(
         self,
         title: str,
+        *,
         description: Optional[str] = None,
         nsfw: bool = False,
         resources: str = None,
     ) -> "praw.models.LiveThread":
-        """Create a new LiveThread.
+        """Create a new :class:`.LiveThread`.
 
-        :param title: The title of the new LiveThread.
-        :param description: (Optional) The new LiveThread's description.
-        :param nsfw: (boolean) Indicate whether this thread is not safe for work
-            (default: False).
-        :param resources: (Optional) Markdown formatted information that is useful for
-            the LiveThread.
+        :param title: The title of the new :class:`.LiveThread`.
+        :param description: The new :class:`.LiveThread`'s description.
+        :param nsfw: Indicate whether this thread is not safe for work (default:
+            ``False``).
+        :param resources: Markdown formatted information that is useful for the
+            :class:`.LiveThread`.
 
-        :returns: The new LiveThread object.
+        :returns: The new :class:`.LiveThread` object.
 
         """
         return self._reddit.post(
@@ -233,51 +236,63 @@ class LiveHelper(PRAWBase):
 
 
 class MultiredditHelper(PRAWBase):
-    """Provide a set of functions to interact with Multireddits."""
+    """Provide a set of functions to interact with multireddits."""
 
+    @_deprecate_args("redditor", "name")
     def __call__(
-        self, redditor: Union[str, "praw.models.Redditor"], name: str
+        self, *, name: str, redditor: Union[str, "praw.models.Redditor"]
     ) -> "praw.models.Multireddit":
-        """Return a lazy instance of :class:`~.Multireddit`.
+        """Return a lazy instance of :class:`.Multireddit`.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
-            instance who owns the multireddit.
         :param name: The name of the multireddit.
+        :param redditor: A redditor name or :class:`.Redditor` instance who owns the
+            multireddit.
 
         """
         path = f"/user/{redditor}/m/{name}"
         return Multireddit(self._reddit, _data={"name": name, "path": path})
 
+    @_deprecate_args(
+        "display_name",
+        "subreddits",
+        "description_md",
+        "icon_name",
+        "key_color",
+        "visibility",
+        "weighting_scheme",
+    )
     def create(
         self,
-        display_name: str,
-        subreddits: Union[str, "praw.models.Subreddit"],
+        *,
         description_md: Optional[str] = None,
+        display_name: str,
         icon_name: Optional[str] = None,
         key_color: Optional[str] = None,
+        subreddits: Union[str, "praw.models.Subreddit"],
         visibility: str = "private",
         weighting_scheme: str = "classic",
     ) -> "praw.models.Multireddit":
-        """Create a new multireddit.
+        """Create a new :class:`.Multireddit`.
 
         :param display_name: The display name for the new multireddit.
-        :param subreddits: Subreddits to add to the new multireddit.
-        :param description_md: (Optional) Description for the new multireddit, formatted
-            in markdown.
-        :param icon_name: (Optional) Can be one of: ``art and design``, ``ask``,
-            ``books``, ``business``, ``cars``, ``comics``, ``cute animals``, ``diy``,
-            ``entertainment``, ``food and drink``, ``funny``, ``games``, ``grooming``,
-            ``health``, ``life advice``, ``military``, ``models pinup``, ``music``,
-            ``news``, ``philosophy``, ``pictures and gifs``, ``science``, ``shopping``,
-            ``sports``, ``style``, ``tech``, ``travel``, ``unusual stories``, ``video``,
-            or ``None``.
-        :param key_color: (Optional) RGB hex color code of the form ``"#FFFFFF"``.
-        :param visibility: (Optional) Can be one of: ``hidden``, ``private``, ``public``
-            (default: private).
-        :param weighting_scheme: (Optional) Can be one of: ``classic``, ``fresh``
-            (default: classic).
+        :param subreddits: Subreddits to add to the new multireddit. Can be a list of
+            either :class:`.Subreddit` instances or subreddit display names.
+        :param description_md: Description for the new multireddit, formatted in
+            markdown.
+        :param icon_name: Can be one of: ``"art and design"``, ``"ask"``, ``"books"``,
+            ``"business"``, ``"cars"``, ``"comics"``, ``"cute animals"``, ``"diy"``,
+            ``"entertainment"``, ``"food and drink"``, ``"funny"``, ``"games"``,
+            ``"grooming"``, ``"health"``, ``"life advice"``, ``"military"``, ``"models
+            pinup"``, ``"music"``, ``"news"``, ``"philosophy"``, ``"pictures and
+            gifs"``, ``"science"``, ``"shopping"``, ``"sports"``, ``"style"``,
+            ``"tech"``, ``"travel"``, ``"unusual stories"``, ``"video"``, or ``None``.
+        :param key_color: RGB hex color code of the form ``"#FFFFFF"``.
+        :param visibility: Can be one of: ``"hidden"``, ``"private"``, or ``"public"``
+            (default: ``"private"``).
+        :param weighting_scheme: Can be one of: ``"classic"`` or ``"fresh"`` (default:
+            ``"classic"``).
 
-        :returns: The new Multireddit object.
+        :returns: The new :class:`.Multireddit` object.
 
         """
         model = {
@@ -298,7 +313,7 @@ class SubredditHelper(PRAWBase):
     """Provide a set of functions to interact with Subreddits."""
 
     def __call__(self, display_name: str) -> "praw.models.Subreddit":
-        """Return a lazy instance of :class:`~.Subreddit`.
+        """Return a lazy instance of :class:`.Subreddit`.
 
         :param display_name: The name of the subreddit.
 
@@ -312,29 +327,32 @@ class SubredditHelper(PRAWBase):
 
         return Subreddit(self._reddit, display_name=display_name)
 
+    @_deprecate_args("name", "title", "link_type", "subreddit_type", "wikimode")
     def create(
         self,
         name: str,
-        title: Optional[str] = None,
+        *,
         link_type: str = "any",
         subreddit_type: str = "public",
+        title: Optional[str] = None,
         wikimode: str = "disabled",
         **other_settings: Optional[str],
     ) -> "praw.models.Subreddit":
-        """Create a new subreddit.
+        """Create a new :class:`.Subreddit`.
 
         :param name: The name for the new subreddit.
+        :param link_type: The types of submissions users can make. One of ``"any"``,
+            ``"link"``, or ``"self"`` (default: ``"any"``).
+        :param subreddit_type: One of ``"archived"``, ``"employees_only"``,
+            ``"gold_only"``, ``"gold_restricted"``, ``"private"``, ``"public"``, or
+            ``"restricted"`` (default: ``"public"``).
         :param title: The title of the subreddit. When ``None`` or ``""`` use the value
             of ``name``.
-        :param link_type: The types of submissions users can make. One of ``any``,
-            ``link``, ``self`` (default: any).
-        :param subreddit_type: One of ``archived``, ``employees_only``, ``gold_only``,
-            ``gold_restricted``, ``private``, ``public``, ``restricted`` (default:
-            public).
-        :param wikimode: One of ``anyone``, ``disabled``, ``modonly``.
+        :param wikimode: One of ``"anyone"``, ``"disabled"``, or ``"modonly"`` (default:
+            ``"disabled"``).
 
-        Any keyword parameters not provided, or set explicitly to None, will take on a
-        default value assigned by the Reddit server.
+        Any keyword parameters not provided, or set explicitly to ``None``, will take on
+        a default value assigned by the Reddit server.
 
         .. seealso::
 
@@ -344,8 +362,8 @@ class SubredditHelper(PRAWBase):
         """
         Subreddit._create_or_update(
             _reddit=self._reddit,
-            name=name,
             link_type=link_type,
+            name=name,
             subreddit_type=subreddit_type,
             title=title or name,
             wikimode=wikimode,
