@@ -19,18 +19,13 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
-    """A class that represents a reddit comment.
+    """A class that represents a Reddit comment.
 
-    **Typical Attributes**
+    .. include:: ../../typical_attributes.rst
 
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
-
-    ================= ==================================================================
+    ================= =================================================================
     Attribute         Description
-    ================= ==================================================================
+    ================= =================================================================
     ``author``        Provides an instance of :class:`.Redditor`.
     ``body``          The body of the comment, as Markdown.
     ``body_html``     The body of the comment, as HTML.
@@ -44,8 +39,8 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     ``parent_id``     The ID of the parent comment (prefixed with ``t1_``). If it is a
                       top-level comment, this returns the submission ID instead
                       (prefixed with ``t3_``).
-    ``permalink``     A permalink for the comment. Comment objects from the inbox have a
-                      ``context`` attribute instead.
+    ``permalink``     A permalink for the comment. :class:`.Comment` objects from the
+                      inbox have a ``context`` attribute instead.
     ``replies``       Provides an instance of :class:`.CommentForest`.
     ``saved``         Whether or not the comment is saved.
     ``score``         The number of upvotes for the comment.
@@ -55,7 +50,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     ``subreddit``     Provides an instance of :class:`.Subreddit`. The subreddit that
                       the comment belongs to.
     ``subreddit_id``  The subreddit ID that the comment belongs to.
-    ================= ==================================================================
+    ================= =================================================================
 
     .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
@@ -84,7 +79,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
     @property
     def is_root(self) -> bool:
-        """Return True when the comment is a top level comment."""
+        """Return ``True`` when the comment is a top-level comment."""
         parent_type = self.parent_id.split("_", 1)[0]
         return parent_type == self._reddit.config.kinds["submission"]
 
@@ -107,7 +102,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         """Provide an instance of :class:`.CommentForest`.
 
         This property may return an empty list if the comment has not been refreshed
-        with :meth:`.refresh()`
+        with :meth:`.refresh`
 
         Sort order and reply limit can be set with the ``reply_sort`` and
         ``reply_limit`` attributes before replies are fetched, including any call to
@@ -121,8 +116,8 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
         .. note::
 
-            The appropriate values for ``reply_sort`` include ``confidence``,
-            ``controversial``, ``new``, ``old``, ``q&a``, and ``top``.
+            The appropriate values for ``reply_sort`` include ``"confidence"``,
+            ``"controversial"``, ``"new"``, ``"old"``, ``"q&a"``, and ``"top"``.
 
         """
         if isinstance(self._replies, list):
@@ -131,14 +126,14 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
     @property
     def submission(self) -> "praw.models.Submission":
-        """Return the Submission object this comment belongs to."""
+        """Return the :class:`.Submission` object this comment belongs to."""
         if not self._submission:  # Comment not from submission
             self._submission = self._reddit.submission(self._extract_submission_id())
         return self._submission
 
     @submission.setter
     def submission(self, submission: "praw.models.Submission"):
-        """Update the Submission associated with the Comment."""
+        """Update the :class:`.Submission` associated with the :class:`.Comment`."""
         submission._comments_by_id[self.fullname] = self
         self._submission = submission
         # pylint: disable=not-an-iterable
@@ -152,9 +147,9 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         url: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
-        """Construct an instance of the Comment object."""
+        """Initialize a :class:`.Comment` instance."""
         if (id, url, _data).count(None) != 2:
-            raise TypeError("Exactly one of `id`, `url`, or `_data` must be provided.")
+            raise TypeError("Exactly one of 'id', 'url', or '_data' must be provided.")
         fetched = False
         self._replies = []
         self._submission = None
@@ -190,7 +185,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     def _fetch_data(self):
         name, fields, params = self._fetch_info()
         path = API_PATH[name].format(**fields)
-        return self._reddit.request("GET", path, params)
+        return self._reddit.request(method="GET", params=params, path=path)
 
     def _fetch(self):
         data = self._fetch_data()
@@ -228,21 +223,20 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
             comment = reddit.comment("cklhv0f")
             parent = comment.parent()
-            # `replies` is empty until the comment is refreshed
+            # 'replies' is empty until the comment is refreshed
             print(parent.replies)  # Output: []
             parent.refresh()
             print(parent.replies)  # Output is at least: [Comment(id="cklhv0f")]
 
         .. warning::
 
-            Successive calls to :meth:`.parent()` may result in a network request per
-            call when the comment is not obtained through a :class:`.Submission`. See
-            below for an example of how to minimize requests.
+            Successive calls to :meth:`.parent` may result in a network request per call
+            when the comment is not obtained through a :class:`.Submission`. See below
+            for an example of how to minimize requests.
 
         If you have a deeply nested comment and wish to most efficiently discover its
         top-most :class:`.Comment` ancestor you can chain successive calls to
-        :meth:`.parent()` with calls to :meth:`.refresh()` at every 9 levels. For
-        example:
+        :meth:`.parent` with calls to :meth:`.refresh` at every 9 levels. For example:
 
         .. code-block:: python
 
@@ -257,7 +251,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
             print(f"Top-most Ancestor: {ancestor}")
 
         The above code should result in 5 network requests to Reddit. Without the calls
-        to :meth:`.refresh()` it would make at least 31 network requests.
+        to :meth:`.refresh` it would make at least 31 network requests.
 
         """
         # pylint: disable=no-member
@@ -324,7 +318,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
 
 class CommentModeration(ThingModerationMixin):
-    """Provide a set of functions pertaining to Comment moderation.
+    """Provide a set of functions pertaining to :class:`.Comment` moderation.
 
     Example usage:
 
@@ -338,7 +332,7 @@ class CommentModeration(ThingModerationMixin):
     REMOVAL_MESSAGE_API = "removal_comment_message"
 
     def __init__(self, comment: "praw.models.Comment"):
-        """Create a CommentModeration instance.
+        """Initialize a :class:`.CommentModeration` instance.
 
         :param comment: The comment to moderate.
 
@@ -346,7 +340,7 @@ class CommentModeration(ThingModerationMixin):
         self.thing = comment
 
     def show(self):
-        """Uncollapse a :class:`~.Comment` that has been collapsed by Crowd Control.
+        """Uncollapse a :class:`.Comment` that has been collapsed by Crowd Control.
 
         Example usage:
 
