@@ -22,7 +22,7 @@ class Objector:
 
         :param data: The dict to be converted.
 
-        :returns: An instance of :class:`~.RedditAPIException`, or ``None`` if ``data``
+        :returns: An instance of :class:`.RedditAPIException`, or ``None`` if ``data``
             doesn't fit this model.
 
         """
@@ -47,24 +47,58 @@ class Objector:
             raise error
 
     def __init__(self, reddit: "praw.Reddit", parsers: Optional[Dict[str, Any]] = None):
-        """Initialize an Objector instance.
+        """Initialize an :class:`.Objector` instance.
 
-        :param reddit: An instance of :class:`~.Reddit`.
+        :param reddit: An instance of :class:`.Reddit`.
 
         """
         self.parsers = {} if parsers is None else parsers
         self._reddit = reddit
 
     def _objectify_dict(self, data):
-        """Create RedditBase objects from dicts.
+        """Create :class:`.RedditBase` objects from dicts.
 
         :param data: The structured data, assumed to be a dict.
 
-        :returns: An instance of :class:`~.RedditBase`.
+        :returns: An instance of :class:`.RedditBase`.
 
         """
-        if {"conversation", "messages", "modActions"}.issubset(data):
+        if {"messages", "modActions"}.issubset(data) and {
+            "conversations",
+            "conversation",
+        }.intersection(data):
+            # fetched conversation
+            data.update(
+                data.pop("conversation")
+                if "conversation" in data
+                else data.pop("conversations")
+            )
             parser = self.parsers["ModmailConversation"]
+            parser._convert_conversation_objects(data, self._reddit)
+        elif {"messages", "modActions"}.issubset(data) or {
+            "legacyFirstMessageId",
+            "state",
+        }.issubset(data):
+            # not fetched conversation i.e., from conversations()
+            del data["objIds"]  # delete objIds since it could be missing data
+            parser = self.parsers["ModmailConversation"]
+        elif {"conversationIds", "conversations", "messages"}.issubset(data):
+            # modmail conversations
+            conversations = []
+            for conversation_id in data["conversationIds"]:
+                conversation = data["conversations"][conversation_id]
+                # set if the numMessages is same as number of messages in objIds
+                if conversation["numMessages"] == len(
+                    [obj for obj in conversation["objIds"] if obj["key"] == "messages"]
+                ):
+                    conversation["messages"] = [
+                        self.objectify(data["messages"][obj_id["id"]])
+                        for obj_id in conversation["objIds"]
+                    ]
+                conversations.append(conversation)
+            data["conversations"] = conversations
+            data = snake_case_keys(data)
+            parser = self.parsers["ModmailConversations-list"]
         elif {"actionTypeId", "author", "date"}.issubset(data):
             # Modmail mod action
             data = snake_case_keys(data)
@@ -150,6 +184,23 @@ class Objector:
                     draft["modified"] / 1000
                 ).astimezone()
             parser = self.parsers["DraftList"]
+        elif {"mod_action_data", "user_note_data"}.issubset(data):
+            data["moderator"] = self._reddit.redditor(data["operator"])
+            data["subreddit"] = self._reddit.subreddit(data["subreddit"])
+            data["user"] = self._reddit.redditor(data["user"])
+            # move these sub dict values into the main dict for simplicity
+            data.update(data["mod_action_data"])
+            del data["mod_action_data"]
+            data.update(data["user_note_data"])
+            del data["user_note_data"]
+            parser = self.parsers["mod_note"]
+        elif (
+            "created" in data
+            and isinstance(data["created"], dict)
+            and {"mod_action_data", "user_note_data"}.issubset(data["created"])
+        ):
+            data = data["created"]
+            return self._objectify_dict(data)
         else:
             if "user" in data:
                 parser = self.parsers[self._reddit.config.kinds["redditor"]]
@@ -160,11 +211,11 @@ class Objector:
     def objectify(
         self, data: Optional[Union[Dict[str, Any], List[Any], bool]]
     ) -> Optional[Union[RedditBase, Dict[str, Any], List[Any], bool]]:
-        """Create RedditBase objects from data.
+        """Create :class:`.RedditBase` objects from data.
 
         :param data: The structured data.
 
-        :returns: An instance of :class:`~.RedditBase`, or ``None`` if given ``data`` is
+        :returns: An instance of :class:`.RedditBase`, or ``None`` if given ``data`` is
             ``None``.
 
         """
