@@ -8,17 +8,19 @@ PRAW users will create their own token manager classes suitable for their needs.
 
 .. deprecated:: 7.4.0
 
-    Tokens managers have been depreciated and will be removed in the near future.
+    Tokens managers have been deprecated and will be removed in the near future.
 
 """
 from abc import ABC, abstractmethod
 
+from . import _deprecate_args
+
 
 class BaseTokenManager(ABC):
     """An abstract class for all token managers."""
 
     def __init__(self):
-        """Prepare attributes needed by all token manager classes."""
+        """Initialize a :class:`.BaseTokenManager` instance."""
         self._reddit = None
 
     @property
@@ -30,7 +32,7 @@ class BaseTokenManager(ABC):
     def reddit(self, value):
         if self._reddit is not None:
             raise RuntimeError(
-                "``reddit`` can only be set once and is done automatically"
+                "'reddit' can only be set once and is done automatically"
             )
         self._reddit = value
 
@@ -75,7 +77,7 @@ class FileTokenManager(BaseTokenManager):
     """
 
     def __init__(self, filename):
-        """Load and save refresh tokens from a file.
+        """Initialize a :class:`.FileTokenManager` instance.
 
         :param filename: The file the contains the refresh token.
 
@@ -99,8 +101,8 @@ class SQLiteTokenManager(BaseTokenManager):
     """Provides a SQLite3 based token manager.
 
     Unlike, :class:`.FileTokenManager`, the initial database need not be created ahead
-    of time, as it'll automatically be created on first use. However, initial
-    ``refresh_tokens`` will need to be registered via :meth:`.register` prior to use.
+    of time, as it'll automatically be created on first use. However, initial refresh
+    tokens will need to be registered via :meth:`.register` prior to use.
 
     .. warning::
 
@@ -109,14 +111,15 @@ class SQLiteTokenManager(BaseTokenManager):
 
     """
 
-    def __init__(self, database, key):
-        """Load and save refresh tokens from a SQLite database.
+    @_deprecate_args("database", "key")
+    def __init__(self, *, database, key):
+        """Initialize a :class:`.SQLiteTokenManager` instance.
 
         :param database: The path to the SQLite database.
-        :param key: The key used to locate the ``refresh_token``. This ``key`` can be
-            anything. You might use the ``client_id`` if you expect to have unique
-            ``refresh_tokens`` for each ``client_id``, or you might use a Redditor's
-            ``username`` if you're manage multiple users' authentications.
+        :param key: The key used to locate the refresh token. This ``key`` can be
+            anything. You might use the ``client_id`` if you expect to have unique a
+            refresh token for each ``client_id``, or you might use a redditor's
+            ``username`` if you're managing multiple users' authentications.
 
         """
         super().__init__()
